import { u as ListBookmarksRequest$1, L as ListBookmarksResponse$1, v as CreateBookmarkRequest$1, w as CreateBookmarkResponse$1, x as DeleteBookmarkRequest$1, y as DeleteBookmarkResponse$1 } from './events-schedule-v1-schedule-item-schedule-bookmarks.universal-DNfhZ_b6.js';

/** Schedule item describes the schedule within an event. Each event may contain multiple schedule items. */
interface ScheduleItem {
    /**
     * Schedule item ID.
     * @format GUID
     * @readonly
     */
    id?: string;
    /** Whether a schedule item is hidden from guests. */
    hidden?: boolean;
    /**
     * Schedule item name.
     * @maxLength 120
     */
    name?: string;
    /** Time slot of a schedule item. */
    timeSlot?: TimeInterval;
    /**
     * Rich text schedule item description.
     * @maxLength 10000
     */
    description?: string;
    /**
     * Stage or room name in which a session takes place.
     * @maxLength 30
     */
    stageName?: string;
    /**
     * Schedule item tags. Used to organize the items by a theme.
     * @maxSize 5
     * @minLength 1
     * @maxLength 30
     */
    tags?: string[];
    /** Schedule item status. */
    status?: ScheduleStatusWithLiterals;
    /**
     * Date and time the schedule item was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the schedule item was updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /**
     * Event ID to which the schedule item belongs.
     * @format GUID
     * @readonly
     */
    eventId?: string;
    /**
     * Whether the schedule item is a draft.
     * @readonly
     */
    draft?: boolean;
}
/** Time interval on the timeline between two points in time. */
interface TimeInterval {
    /** Start of the time slot interval, inclusive. */
    start?: Date | null;
    /** End of the time slot interval, exclusive. */
    end?: Date | null;
    /**
     * Time zone ID in TZ database format, e.g., `"EST"`, `"America/Los_Angeles"`.
     * Defaults to `"Etc/UTC"` when not set.
     * @minLength 1
     * @maxLength 100
     */
    timeZoneId?: string | null;
}
declare enum ScheduleStatus {
    /** Item is scheduled for a future date. */
    SCHEDULED = "SCHEDULED",
    /** Item is canceled. */
    CANCELED = "CANCELED"
}
/** @enumType */
type ScheduleStatusWithLiterals = ScheduleStatus | 'SCHEDULED' | 'CANCELED';
interface ListBookmarksRequest {
    /**
     * Event ID to which the schedule item belongs.
     * @format GUID
     */
    eventId: string;
}
interface ListBookmarksResponse {
    /** Schedule items. */
    items?: ScheduleItem[];
}
interface CreateBookmarkRequest {
    /**
     * Event ID to which the schedule item belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Schedule item ID.
     * @format GUID
     */
    itemId: string;
}
interface CreateBookmarkResponse {
}
interface DeleteBookmarkRequest {
    /**
     * Event ID to which the schedule item belongs.
     * @format GUID
     */
    eventId: string;
    /**
     * Schedule item ID.
     * @format GUID
     */
    itemId: string;
}
interface DeleteBookmarkResponse {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function listBookmarks(): __PublicMethodMetaInfo<'GET', {}, ListBookmarksRequest$1, ListBookmarksRequest, ListBookmarksResponse$1, ListBookmarksResponse>;
declare function createBookmark(): __PublicMethodMetaInfo<'POST', {
    itemId: string;
}, CreateBookmarkRequest$1, CreateBookmarkRequest, CreateBookmarkResponse$1, CreateBookmarkResponse>;
declare function deleteBookmark(): __PublicMethodMetaInfo<'DELETE', {
    itemId: string;
}, DeleteBookmarkRequest$1, DeleteBookmarkRequest, DeleteBookmarkResponse$1, DeleteBookmarkResponse>;

export { type __PublicMethodMetaInfo, createBookmark, deleteBookmark, listBookmarks };
